==> spip_3.1.3.orig.tar.xz: spip/plugins-dist/mots/lang/mots_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>مجموعة مهمة:</b> ينصح بالحاح اختيار مفتاح من هذه المجموعة.',
	'avis_doublon_mot_cle' => 'هناك مفتاح موجود بهذا الاسم. هل انت متأكد من استخدام الاسم نفسه؟',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'مدراء الموقع',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'المحررون',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'زوار الموقع العمومي حين يرسلون مشاركة الى المنتدى',

	// C
	'creer_et_associer_un_mot' => 'إنشاء مفتاح وربطه',

	// I
	'icone_creation_groupe_mots' => 'إنشاء مجموعة جديدة',
	'icone_creation_mots_cles' => 'إنشاء مفتاح جديد',
	'icone_modif_groupe_mots' => 'تغيير مجموعة المفاتيح هذه',
	'icone_modifier_mot' => 'تغيير هذا المفتاح',
	'icone_mots_cles' => 'المفاتيح',
	'icone_supprimer_groupe_mots' => 'حذف هذه المجموعة',
	'icone_voir_groupe_mots' => 'عرض مجموعة المفاتيح',
	'icone_voir_tous_mots_cles' => 'عرض كل المفاتيح',
	'info_1_groupe_mots' => 'مجموعة مفاتيح واحدة',
	'info_articles_lies_mot' => 'المقالات المرتبطة بهذا المفتاح',
	'info_aucun_groupe_mots' => 'لا يوجد مجموعات مفاتيح',
	'info_aucun_mot_cle' => 'لا مفتاح',
	'info_changer_nom_groupe' => 'تغيير إسم هذه المجموعة:',
	'info_creation_mots_cles' => 'إنشاء مفاتيح الموقع وتنسيقها من هنا',
	'info_dans_groupe' => 'في المجموعة:',
	'info_delet_mots_cles' => 'طلبت حذف المفتاح
&lt;b&gt;@titre_mot@&lt;/b&gt; (@type_mot@). بما أن هذا المفتاح مرتبط بـ&lt;b&gt;@texte_lie@&lt;/b&gt;، يجب تأكيد هذا القرار:',
	'info_groupe_important' => 'مجموعة مهمة',
	'info_modifier_mot' => 'تغيير المفتاح:',
	'info_mots_cles' => 'المفاتيح',
	'info_mots_cles_association' => 'يمكن ربط مفاتيح هذه المجموعة بـ:',
	'info_nb_groupe_mots' => '@nb@ مجموعة مفاتيح',
	'info_oui_suppression_mot_cle' => 'أرغب في حذف هذا المفتاح نهائياً.',
	'info_question_mots_cles' => 'هل تريد استخدام المفاتيح في موقعك؟',
	'info_qui_attribue_mot_cle' => 'يمكن تخصيص المفاتيح في هذه المجموعة من قبل:',
	'info_remplacer_mot' => 'استبدال "@titre@"',
	'info_retirer_mot' => 'حذف هذا المفتاح',
	'info_retirer_mots' => 'حذف كل المفاتيح',
	'info_rubriques_liees_mot' => 'الأقسام المرتبطة بهذا المفتاح',
	'info_selection_un_seul_mot_cle' => 'يمكنك تحديد &lt;b&gt;مفتاح واحد فقط&lt;/b&gt;  في وقت واحد من هذه المجموعة.',
	'info_supprimer_mot' => 'حذف هذا المفتاح',
	'info_titre_mot_cle' => 'إسم أو عنوان هذا المفتاح',
	'info_un_mot' => 'مفتاح واحد في وقت واحد',
	'item_ajout_mots_cles' => 'السماح بإضافة المفاتيح الى المنتديات',
	'item_non_ajout_mots_cles' => 'عدم السماح باستخدام المفاتيح في المنتديات',
	'item_non_utiliser_config_groupe_mots_cles' => 'عدم استخدام إعداد مجموعات المفاتيح المتطور',
	'item_non_utiliser_mots_cles' => 'عدم استخدام المفاتيح',
	'item_utiliser_config_groupe_mots_cles' => 'إستخدام إعداد مجموعات المفاتيح المتطور',
	'item_utiliser_mots_cles' => 'إستخدام المفاتيح',

	// L
	'lien_ajouter_mot' => 'إضافة هذا المفتاح',
	'logo_groupe' => 'شعار هذه المجموعة',
	'logo_mot_cle' => 'شعار المفتاح',

	// T
	'texte_config_groupe_mots_cles' => 'هل تريد تفعيل إعداد مجموعات المفاتيح المتطور بتحديد، مثلاً، إمكان اختيار مفتاح وحيد في كل مجموعة او التشديد على اهمية مجموعة معينة...؟',
	'texte_mots_cles' => 'تتيح لك المفاتيح إنشاء روابط بين المقالات تعتمد على مواضيعها
بغض النظر عن انتمائها الى الأقسام. يمكنك هكذا
تحسين تصفح موقعك او حتى استخدام هذه الخصائص
لتخصيص المقالات في صفحاتك النموذجية.',
	'texte_mots_cles_dans_forum' => 'هل تريد السماح باستخدام المفاتيح التي يمكن للزوار اختيارها في منتديات الموقع العمومي؟ (تحذير: الاستخدام السليم لهذا الخيار معقد بعض الشيء).',
	'texte_nouveau_mot' => 'مفتاح جديد',
	'titre_config_groupe_mots_cles' => 'إعداد مجموعات المفاتيح',
	'titre_gauche_mots_edit' => 'مفتاح رقم:',
	'titre_groupe_mots' => 'مجموعة مفاتيح',
	'titre_groupe_mots_numero' => 'مجموعة مفاتيح رقم:',
	'titre_groupes_mots' => 'مجموعة مفاتيح',
	'titre_mots_cles_dans_forum' => 'المفاتيح في منتديات الموقع العمومي',
	'titre_mots_tous' => 'المفاتيح',
	'titre_nouveau_groupe' => 'مجموعة جديدة',
	'titre_objets_lies_mot' => 'مرتبطة بهذا المفتاح:',
	'titre_page_mots_tous' => 'المفاتيح'
);

?>

==> spip_3.2.4.orig.tar.xz: spip/plugins-dist/mots/lang/mots_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>مجموعة مهمة:</b> ينصح بالحاح اختيار مفتاح من هذه المجموعة.',
	'avis_doublon_mot_cle' => 'هناك مفتاح موجود بهذا الاسم. هل انت متأكد من استخدام الاسم نفسه؟',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'مدراء الموقع',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'المحررون',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'زوار الموقع العمومي حين يرسلون مشاركة الى المنتدى',

	// C
	'creer_et_associer_un_mot' => 'إنشاء مفتاح وربطه',

	// I
	'icone_creation_groupe_mots' => 'إنشاء مجموعة جديدة',
	'icone_creation_mots_cles' => 'إنشاء مفتاح جديد',
	'icone_modif_groupe_mots' => 'تغيير مجموعة المفاتيح هذه',
	'icone_modifier_mot' => 'تغيير هذا المفتاح',
	'icone_mots_cles' => 'المفاتيح',
	'icone_supprimer_groupe_mots' => 'حذف هذه المجموعة',
	'icone_voir_groupe_mots' => 'عرض مجموعة المفاتيح',
	'icone_voir_tous_mots_cles' => 'عرض كل المفاتيح',
	'info_1_groupe_mots' => 'مجموعة مفاتيح واحدة',
	'info_articles_lies_mot' => 'المقالات المرتبطة بهذا المفتاح',
	'info_aucun_groupe_mots' => 'لا يوجد مجموعات مفاتيح',
	'info_aucun_mot_cle' => 'لا مفتاح',
	'info_changer_nom_groupe' => 'تغيير إسم هذه المجموعة:',
	'info_creation_mots_cles' => 'إنشاء مفاتيح الموقع وتنسيقها من هنا',
	'info_dans_groupe' => 'في المجموعة:',
	'info_delet_mots_cles' => 'طلبت حذف المفتاح
&lt;b&gt;@titre_mot@&lt;/b&gt; (@type_mot@). بما أن هذا المفتاح مرتبط بـ&lt;b&gt;@texte_lie@&lt;/b&gt;، يجب تأكيد هذا القرار:',
	'info_groupe_important' => 'مجموعة مهمة',
	'info_modifier_mot' => 'تغيير المفتاح:',
	'info_mots_cles' => 'المفاتيح',
	'info_mots_cles_association' => 'يمكن ربط مفاتيح هذه المجموعة بـ:',
	'info_nb_groupe_mots' => '@nb@ مجموعة مفاتيح',
	'info_oui_suppression_mot_cle' => 'أرغب في حذف هذا المفتاح نهائياً.',
	'info_question_mots_cles' => 'هل تريد استخدام المفاتيح في موقعك؟',
	'info_qui_attribue_mot_cle' => 'يمكن تخصيص المفاتيح في هذه المجموعة من قبل:',
	'info_remplacer_mot' => 'استبدال "@titre@"',
	'info_retirer_mot' => 'حذف هذا المفتاح',
	'info_retirer_mots' => 'حذف كل المفاتيح',
	'info_rubriques_liees_mot' => 'الأقسام المرتبطة بهذا المفتاح',
	'info_selection_un_seul_mot_cle' => 'يمكنك تحديد &lt;b&gt;مفتاح واحد فقط&lt;/b&gt;  في وقت واحد من هذه المجموعة.',
	'info_supprimer_mot' => 'حذف هذا المفتاح',
	'info_titre_mot_cle' => 'إسم أو عنوان هذا المفتاح',
	'info_un_mot' => 'مفتاح واحد في وقت واحد',
	'item_ajout_mots_cles' => 'السماح بإضافة المفاتيح الى المنتديات',
	'item_non_ajout_mots_cles' => 'عدم السماح باستخدام المفاتيح في المنتديات',
	'item_non_utiliser_config_groupe_mots_cles' => 'عدم استخدام إعداد مجموعات المفاتيح المتطور',
	'item_non_utiliser_mots_cles' => 'عدم استخدام المفاتيح',
	'item_utiliser_config_groupe_mots_cles' => 'إستخدام إعداد مجموعات المفاتيح المتطور',
	'item_utiliser_mots_cles' => 'إستخدام المفاتيح',

	// L
	'lien_ajouter_mot' => 'إضافة هذا المفتاح',
	'logo_groupe' => 'رمز هذه المجموعة',
	'logo_mot_cle' => 'رمز المفتاح',

	// T
	'texte_config_groupe_mots_cles' => 'هل تريد تفعيل إعداد مجموعات المفاتيح المتطور بتحديد، مثلاً، إمكان اختيار مفتاح وحيد في كل مجموعة او التشديد على اهمية مجموعة معينة...؟',
	'texte_mots_cles' => 'تتيح لك المفاتيح إنشاء روابط بين المقالات تعتمد على مواضيعها
بغض النظر عن انتمائها الى الأقسام. يمكنك هكذا
تحسين تصفح موقعك او حتى استخدام هذه الخصائص
لتخصيص المقالات في صفحاتك النموذجية.',
	'texte_mots_cles_dans_forum' => 'هل تريد السماح باستخدام المفاتيح التي يمكن للزوار اختيارها في منتديات الموقع العمومي؟ (تحذير: الاستخدام السليم لهذا الخيار معقد بعض الشيء).',
	'texte_nouveau_mot' => 'مفتاح جديد',
	'titre_config_groupe_mots_cles' => 'إعداد مجموعات المفاتيح',
	'titre_gauche_mots_edit' => 'مفتاح رقم:',
	'titre_groupe_mots' => 'مجموعة مفاتيح',
	'titre_groupe_mots_numero' => 'مجموعة مفاتيح رقم:',
	'titre_groupes_mots' => 'مجموعة مفاتيح',
	'titre_mots_cles_dans_forum' => 'المفاتيح في منتديات الموقع العمومي',
	'titre_mots_tous' => 'المفاتيح',
	'titre_nouveau_groupe' => 'مجموعة جديدة',
	'titre_objets_lies_mot' => 'مرتبطة بهذا المفتاح:',
	'titre_page_mots_tous' => 'المفاتيح'
);
